==> huaweicloudsdksis-3.0.73-py2.py3-none-any.whl: huaweicloudsdksis/v1/model/word_pronunciation.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class WordPronunciation:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'score': 'float',
        'gop': 'float'
    }

    attribute_map = {
        'score': 'score',
        'gop': 'gop'
    }

    def __init__(self, score=None, gop=None):
        """WordPronunciation - a model defined in huaweicloud sdk"""
        
        

        self._score = None
        self._gop = None
        self.discriminator = None

        self.score = score
        self.gop = gop

    @property
    def score(self):
        """Gets the score of this WordPronunciation.

        单词发音综合得分 0-100

        :return: The score of this WordPronunciation.
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this WordPronunciation.

        单词发音综合得分 0-100

        :param score: The score of this WordPronunciation.
        :type: float
        """
        self._score = score

    @property
    def gop(self):
        """Gets the gop of this WordPronunciation.

        单词发音好坏得分 0-100

        :return: The gop of this WordPronunciation.
        :rtype: float
        """
        return self._gop

    @gop.setter
    def gop(self, gop):
        """Sets the gop of this WordPronunciation.

        单词发音好坏得分 0-100

        :param gop: The gop of this WordPronunciation.
        :type: float
        """
        self._gop = gop

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WordPronunciation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksis-3.0.107-py2.py3-none-any.whl: huaweicloudsdksis/v1/model/word_pronunciation.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class WordPronunciation:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'score': 'float',
        'gop': 'float'
    }

    attribute_map = {
        'score': 'score',
        'gop': 'gop'
    }

    def __init__(self, score=None, gop=None):
        """WordPronunciation

        The model defined in huaweicloud sdk

        :param score: 单词发音综合得分 0-100
        :type score: float
        :param gop: 单词发音好坏得分 0-100
        :type gop: float
        """
        
        

        self._score = None
        self._gop = None
        self.discriminator = None

        self.score = score
        self.gop = gop

    @property
    def score(self):
        """Gets the score of this WordPronunciation.

        单词发音综合得分 0-100

        :return: The score of this WordPronunciation.
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this WordPronunciation.

        单词发音综合得分 0-100

        :param score: The score of this WordPronunciation.
        :type score: float
        """
        self._score = score

    @property
    def gop(self):
        """Gets the gop of this WordPronunciation.

        单词发音好坏得分 0-100

        :return: The gop of this WordPronunciation.
        :rtype: float
        """
        return self._gop

    @gop.setter
    def gop(self, gop):
        """Sets the gop of this WordPronunciation.

        单词发音好坏得分 0-100

        :param gop: The gop of this WordPronunciation.
        :type gop: float
        """
        self._gop = gop

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WordPronunciation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
